@@ -5,9 +5,8 @@ use crate::{
     mode::Mode,
 };
 use swc_atoms::js_word;
-use swc_common::Spanned;
+use swc_common::{util::take::Take, Spanned};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{ident::IdentLike, undefined, ExprExt, Type, Value::Known};
 
 /// Methods related to the options `bools` and `bool_as_ints`.
