@@ -1,7 +1,7 @@
 use super::Optimizer;
 use crate::mode::Mode;
+use swc_common::util::take::Take;
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::ident::IdentLike;
 
 /// Methods related to option `dead_code`.
